==> bowtie-0.0.12-py2.py3-none-any.whl: bowtie/src/progress.jsx <==
import React from 'react';
import {Circle} from 'rc-progress';
import 'rc-progress/assets/index.css';

var msgpack = require('msgpack-lite');

export default class Progress extends React.Component {
    constructor(props) {
        super(props);
        this.state = {percent: 0, visible: false};
    }

    percent = data => {
        var arr = new Uint8Array(data['data']);
        this.setState({percent: msgpack.decode(arr)});
    }

    increment = data => {
        var arr = new Uint8Array(data['data']);
        this.setState({percent: this.state.percent + msgpack.decode(arr)});
    }

    visible = data => {
        var arr = new Uint8Array(data['data']);
        this.setState({visible: msgpack.decode(arr)});
    }

    componentDidMount() {
        var uuid = this.props.uuid;
        var socket = this.props.socket;

        socket.on(uuid + '#percent', this.percent);
        socket.on(uuid + '#visible', this.visible);
        socket.on(uuid + '#inc', this.increment);
    }

    render() {
        if (this.state.visible) {
            return (
                <div style={{display: 'flex', flex: '1 1 0', alignItems: 'center', justifyContent: 'center', alignContent: 'center'}}>
                <Circle
                    percent={this.state.percent}
                    strokeWidth="6"
                    strokeLinecap="round"
                    strokeColor={this.props.color}
                    style={{width: '70%', height: '70%', alignSelf: 'center'}}
                />
                </div>
            );
        } else {
            return (
                this.props.children
            );
        }
    }
}

Progress.propTypes = {
    uuid: React.PropTypes.string.isRequired,
    socket: React.PropTypes.object.isRequired,
    color: React.PropTypes.string.isRequired,
    children: React.PropTypes.any
};

==> bowtie-0.2.2-py2.py3-none-any.whl: bowtie/src/progress.jsx <==
import React from 'react';
import { Progress } from 'antd';
import 'antd/dist/antd.css';

var msgpack = require('msgpack-lite');

export default class CProgress extends React.Component {
    constructor(props) {
        super(props);
        this.state = {percent: 0, visible: false, status: 'active'};
    }

    percent = data => {
        var arr = new Uint8Array(data['data']);
        this.setState({percent: msgpack.decode(arr)});
    }

    increment = data => {
        var arr = new Uint8Array(data['data']);
        this.setState({percent: this.state.percent + msgpack.decode(arr)});
    }

    visible = data => {
        var arr = new Uint8Array(data['data']);
        this.setState({visible: msgpack.decode(arr)});
    }

    active = data => {
        this.setState({status: 'active'});
    }

    success = data => {
        this.setState({status: 'success'});
    }

    error = data => {
        this.setState({status: 'exception'});
    }

    componentDidMount() {
        var uuid = this.props.uuid;
        var socket = this.props.socket;

        socket.on(uuid + '#percent', this.percent);
        socket.on(uuid + '#visible', this.visible);
        socket.on(uuid + '#inc', this.increment);
        socket.on(uuid + '#active', this.active);
        socket.on(uuid + '#success', this.success);
        socket.on(uuid + '#error', this.error);
    }

    render() {
        if (this.state.visible) {
            return (
                <div style={{display: 'flex', flex: '1 1 0', alignItems: 'center', justifyContent: 'center', alignContent: 'center'}}>
                <Progress
                    type="circle"
                    showInfo
                    status={this.state.status}
                    percent={this.state.percent}
                    style={{alignSelf: 'center'}}
                />
                </div>
            );
        } else {
            return (
                this.props.children
            );
        }
    }
}

CProgress.propTypes = {
    uuid: React.PropTypes.string.isRequired,
    socket: React.PropTypes.object.isRequired,
    children: React.PropTypes.any
};
